@@ -172,11 +172,13 @@ class WPScanJsonParser(_Parser):
             self.scan_finished = ScanFinished(self.data, **parser_config)
         else:
             self.scan_finished = None
+
         # Add Scan aborted error
         if self.data.get("scan_aborted", None):
             self.error = "Scan Aborted: {}".format(self.data["scan_aborted"])
         else:
             self.error = None
+
         # All all components to list
         self.components = [
             c
@@ -200,20 +202,18 @@ class WPScanJsonParser(_Parser):
         for component in self.components:
             infos.extend(component.get_infos())
 
-            # If all vulns are ignored, add component message to infos
-            component_warnings = [
-                warning
-                for warning in component.get_warnings()
-                if not self.is_false_positive(warning)
-            ]
-            # Automatically add wp item infos if all vuln are ignored and component does not present another issue
             if (
-                len(component_warnings) == 1
-                and "The version could not be determined" in component_warnings[0]
-                and not "Directory listing is enabled" in component_warnings[0]
-                and not "An error log file has been found" in component_warnings[0]
+                isinstance(component, _CoreFinding)
+                and component.component_is_false_positive()
             ):
-                infos.extend(component_warnings)
+                # If all vulns are ignored, add component message to infos
+                actually_false_positives = [
+                    warning
+                    for warning in component.get_warnings()
+                    if not self.is_false_positive(warning)
+                ]
+                # Automatically add wp item infos if all vuln are ignored and component does not present another issue
+                infos.extend(actually_false_positives)
 
             for alert in component.get_alerts() + component.get_warnings():
                 if self.is_false_positive(alert):
@@ -225,21 +225,22 @@ class WPScanJsonParser(_Parser):
         """Get all warnings from all components and igore false positives and automatically remove special warning if all vuln are ignored"""
         warnings = []
         for component in self.components:
+
             # Ignore false positives warnings
-            component_warnings = [
-                warning
-                for warning in component.get_warnings()
-                if not self.is_false_positive(warning)
-            ]
-            # Automatically remove wp item warning if all vuln are ignored and component does not present another issue
             if (
-                len(component_warnings) == 1
-                and "The version could not be determined" in component_warnings[0]
-                and not "Directory listing is enabled" in component_warnings[0]
-                and not "An error log file has been found" in component_warnings[0]
+                isinstance(component, _CoreFinding)
+                and component.component_is_false_positive()
             ):
+                # Automatically remove wp item warning if all vuln are ignored and component does not present another issue
                 component_warnings = []
 
+            else:
+                component_warnings = [
+                    warning
+                    for warning in component.get_warnings()
+                    if not self.is_false_positive(warning)
+                ]
+
             warnings.extend(component_warnings)
 
         return warnings
@@ -293,6 +294,6 @@ class WPScanJsonParser(_Parser):
 
     def get_error(self):
         if self.error:
-            return "WPScan failed: {}".format(self.error)
+            return self.error
         else:
             return None
